#
# spec file for package pantheon-notifications
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.notifications
Name:           pantheon-notifications
Version:        8.0.0
Release:        2.3
Summary:        Notification Server
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/notifications
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         fix-leap.patch
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libhandy-1)
Provides:       elementary-notifications = %{version}
Obsoletes:      elementary-notifications < %{version}

%description
A Gtk notification server for Pantheon desktop.

%package        demo
Summary:        Pantheon Notification Server -- Demo binary

%description    demo
A Gtk notification server for Pantheon desktop.

This package contains a small demo app to send notifications.

%prep
%autosetup -N -n notifications-%{version}
%if 0%{?suse_version} < 1600
%patch -P0 -p1
%endif

%build
%meson
%meson_build

%install
%meson_install
%fdupes %{buildroot}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/metainfo/%{appid}.metainfo.xml
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml

%files demo
%{_bindir}/%{appid}.demo
%{_datadir}/applications/%{appid}.demo.desktop

%changelog
* Tue Nov 19 2024 Richard Rahl <rrahl0@opensuse.org>
- do not patch Leap 16 with fix-leap.patch, as it breaks the build
* Wed Nov  6 2024 Richard Rahl <rrahl0@opensuse.org>
- remove %%suse_update_deskop_file, as it's deprecated
* Wed Oct  2 2024 Richard Rahl <rrahl0@opensuse.org>
- fix leap 16 by including fix-leap.patch in build
* Mon Sep 23 2024 Richard Rahl <rrahl0@opensuse.org>
- adjust %%patch to the newer %%patch -P format
* Thu Aug 29 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Updated translations
- update to 7.0.1:
  * Block GSD "Automatic Suspend" notifications
  * Updated translations
- update to 7.0.0:
  * Increase sound and brightness notifications width to match other
    notifications
  * Updated translations
- update to 6.0.3:
  * Updated translations
- update to 6.0.2:
  * Fix missing icon when set from icon name
  * Updated translations
- switch url to github, as we don't want to link to a different OS
- rename to official naming
* Wed Apr 20 2022 Alexei Podvalsky <avvissu@yandex.by>
- Update to 6.0.1:
  * Remove old issue templates (#136)
  * Application: use startup and dbus_register instead of
    activate (#168)
  * Improve style in places (#164)
  * Move dark theme handling to the Application class (#166)
  * Replace ButtonBox with Box (#161)
  * Replace add with attach for Grid (#159)
* Mon Sep  6 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 6.0.0+git20210906.8a44793:
  * Release 6.0.0 (#144)
  * Update release.yml
  * Add support for image-data (#123)
  * AbstractButton: Don't propagate events after close button
    click (#143)
  * Move Image/Icon logic to Notification class (#140)
  * Play different sound when notification is urgent (#85)
  * Add a badge with set_icon (#133)
  * Notification: get app_name fallback from appinfo (#130)
  * Bubble: wrap between characters if needed (#132)
  * Bubble: don't pack action area for default action (#129)
  * Support Actions (#15)
  * Bubble: use FileIcon instead of pixbuf (#121)
  * Fix #117: Show icons for daemons (#118)
  * Handle URIs used for application icons (#119) (#120)
  * AbstractBubble: Don't accept focus (#114)
  * LINGUAS: Sort and remove en
  * Confirmation: Add flat class to Progressbar (#102)
  * Notification: sanitize markup (#101)
  * Allow entries to activate send (#100)
  * Demo: misc cleanup (#97)
  * Add a demo (#96)
  * Update README.md
  * Swipe gesture to close notifications (#89)
  * Move actions to Notification (#93)
  * Create notification object (#88)
  * Create feature_request.md
  * Create bug_report.md
  * Update config.yml
  * Update and rename .github/ISSUE_TEMPLATES/config.yml to
    .github/ISSUE_TEMPLATE/config.yml
  * Create config.yml
  * Bubble: use alternate syntax for multiple properties (#80)
  * Remove lots of CSS (#79)
  * Fix label width
* Tue Jun 11 2019 Alexei Podvalsky <avvissu@yandex.by>
- Initial package
